@@ -232,7 +232,7 @@ impl Session {
             .await
             .clone()
             .into_iter()
-            .sorted_by(|(_, lhs_name), (_, rhs_name)| data_name.cmp_distance(&lhs_name, &rhs_name))
+            .sorted_by(|(_, lhs_name), (_, rhs_name)| data_name.cmp_distance(lhs_name, rhs_name))
             .take(NUM_OF_ELDERS_SUBSET_FOR_QUERIES)
             .map(|(addr, _)| addr)
             .collect();
