@@ -9,7 +9,7 @@
 use crate::dbs;
 use crate::messaging::{data::Error as ErrorMessage, MessageId, WireMsg};
 use crate::routing::Prefix;
-use crate::types::{DataAddress, Error as DtError, PublicKey};
+use crate::types::{convert_dt_error_to_error_message, DataAddress, PublicKey};
 use std::io;
 use thiserror::Error;
 use xor_name::XorName;
@@ -163,9 +163,6 @@ pub enum Error {
     /// Failed to send message to connection.
     #[error("Failed to send message to connection: {{0.0}}")]
     UnableToSend(WireMsg),
-    /// Sled Failed to create the database
-    #[error("Could not create the register database")]
-    UnableToCreateRegisterDb,
     /// Sled error.
     #[error("Sled error:: {0}")]
     Sled(#[from] sled::Error),
@@ -185,13 +182,3 @@ pub(crate) fn convert_to_error_message(error: Error) -> ErrorMessage {
         }
     }
 }
-pub(crate) fn convert_dt_error_to_error_message(error: DtError) -> ErrorMessage {
-    match error {
-        DtError::InvalidOperation => {
-            ErrorMessage::InvalidOperation("DtError::InvalidOperation".to_string())
-        }
-        DtError::NoSuchEntry => ErrorMessage::NoSuchEntry,
-        DtError::AccessDenied(pk) => ErrorMessage::AccessDenied(pk),
-        other => ErrorMessage::InvalidOperation(format!("DtError: {:?}", other)),
-    }
-}
