@@ -16,7 +16,7 @@ use crate::node::{
     chunk_store::ChunkStore,
     event_mapping::MsgContext,
     node_ops::{NodeDuties, NodeDuty},
-    Node, Result,
+    Error, Node, Result,
 };
 use crate::routing::ELDER_SIZE;
 use std::sync::Arc;
@@ -210,7 +210,7 @@ impl Node {
                     let mut ops = vec![
                         adult
                             .chunks
-                            .write(&write, msg_id, *data_auth.public_key())
+                            .write(&write, msg_id, data_auth.public_key)
                             .await?,
                     ];
                     ops.extend(adult.chunks.check_storage().await?);
@@ -308,7 +308,7 @@ impl Node {
                             .meta_data
                             .write()
                             .await
-                            .read(query, msg_id, *data_auth.public_key(), origin)
+                            .read(query, msg_id, data_auth.public_key, origin)
                             .await?,
                     ];
                     Ok(NodeTask::from(duties))
@@ -355,15 +355,28 @@ impl Node {
                 });
                 Ok(NodeTask::Thread(handle))
             }
-            NodeDuty::ReplicateChunk { chunk, .. } => {
-                let adult = self.as_adult().await?;
-                let handle = tokio::spawn(async move {
-                    Ok(NodeTask::from(vec![
-                        adult.chunks.store_for_replication(chunk).await?,
-                    ]))
-                });
-                Ok(NodeTask::Thread(handle))
-            }
+            NodeDuty::ReplicateChunk { chunk, .. } => match self.as_adult().await {
+                Ok(adult) => {
+                    let handle = tokio::spawn(async move {
+                        Ok(NodeTask::from(vec![
+                            adult.chunks.store_for_replication(chunk).await?,
+                        ]))
+                    });
+                    Ok(NodeTask::Thread(handle))
+                }
+                Err(error) => match error {
+                    Error::NotAnAdult => {
+                        let elder = self.as_elder().await?;
+                        let handle = tokio::spawn(async move {
+                            Ok(NodeTask::from(vec![
+                                elder.meta_data.read().await.republish_chunk(chunk).await?,
+                            ]))
+                        });
+                        Ok(NodeTask::Thread(handle))
+                    }
+                    some_other_error => Err(some_other_error),
+                },
+            },
             NodeDuty::NoOp => Ok(NodeTask::None),
         }
     }
