@@ -6,9 +6,7 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use crate::messaging::{
-    node::Peer, BlsShareSigned, NodeMsgAuthority, NodeSigned, SectionSigned, SrcLocation,
-};
+use crate::messaging::{node::Peer, NodeMsgAuthority, SrcLocation};
 use crate::routing::{
     ed25519::{self},
     error::{Error, Result},
@@ -34,46 +32,34 @@ pub(crate) trait NodeMsgAuthorityUtils {
 impl NodeMsgAuthorityUtils for NodeMsgAuthority {
     fn src_location(&self) -> SrcLocation {
         match self {
-            NodeMsgAuthority::Node(NodeSigned {
-                public_key,
-                section_pk,
-                ..
-            }) => SrcLocation::Node {
-                name: ed25519::name(public_key),
-                section_pk: *section_pk,
+            NodeMsgAuthority::Node(node_auth) => SrcLocation::Node {
+                name: ed25519::name(&node_auth.public_key),
+                section_pk: node_auth.section_pk,
             },
-            NodeMsgAuthority::BlsShare(BlsShareSigned {
-                src_name,
-                section_pk,
-                ..
-            }) => SrcLocation::Section {
-                name: *src_name,
-                section_pk: *section_pk,
+            NodeMsgAuthority::BlsShare(bls_share_auth) => SrcLocation::Section {
+                name: bls_share_auth.src_name,
+                section_pk: bls_share_auth.section_pk,
             },
-            NodeMsgAuthority::Section(SectionSigned {
-                src_name,
-                section_pk,
-                ..
-            }) => SrcLocation::Section {
-                name: *src_name,
-                section_pk: *section_pk,
+            NodeMsgAuthority::Section(section_auth) => SrcLocation::Section {
+                name: section_auth.src_name,
+                section_pk: section_auth.section_pk,
             },
         }
     }
 
     fn name(&self) -> XorName {
         match self {
-            NodeMsgAuthority::Node(NodeSigned { public_key, .. }) => ed25519::name(public_key),
-            NodeMsgAuthority::BlsShare(BlsShareSigned { src_name, .. }) => *src_name,
-            NodeMsgAuthority::Section(SectionSigned { src_name, .. }) => *src_name,
+            NodeMsgAuthority::Node(node_auth) => ed25519::name(&node_auth.public_key),
+            NodeMsgAuthority::BlsShare(bls_share_auth) => bls_share_auth.src_name,
+            NodeMsgAuthority::Section(section_auth) => section_auth.src_name,
         }
     }
 
     // If this location is `Node`, returns the corresponding `Peer` with `addr`. Otherwise error.
     fn peer(&self, addr: SocketAddr) -> Result<Peer> {
         match self {
-            NodeMsgAuthority::Node(NodeSigned { public_key, .. }) => {
-                Ok(Peer::new(ed25519::name(public_key), addr))
+            NodeMsgAuthority::Node(node_auth) => {
+                Ok(Peer::new(ed25519::name(&node_auth.public_key), addr))
             }
             NodeMsgAuthority::Section(_) | NodeMsgAuthority::BlsShare(_) => {
                 Err(Error::InvalidSrcLocation)
@@ -84,12 +70,11 @@ impl NodeMsgAuthorityUtils for NodeMsgAuthority {
     // Verify if the section key of the NodeMsgAuthority can be trusted
     // based on a set of known keys.
     fn verify_src_section_key(&self, known_keys: &[BlsPublicKey]) -> bool {
-        match &self {
-            NodeMsgAuthority::Node(_) => true,
-            NodeMsgAuthority::BlsShare(BlsShareSigned { section_pk, .. })
-            | NodeMsgAuthority::Section(SectionSigned { section_pk, .. }) => {
-                known_keys.iter().any(|key| key == section_pk)
-            }
-        }
+        let section_pk = match &self {
+            NodeMsgAuthority::Node(_) => return true,
+            NodeMsgAuthority::BlsShare(bls_share_auth) => &bls_share_auth.section_pk,
+            NodeMsgAuthority::Section(section_auth) => &section_auth.section_pk,
+        };
+        known_keys.iter().any(|key| key == section_pk)
     }
 }
