@@ -9,8 +9,9 @@
 use super::{Command, Event};
 use crate::messaging::{
     node::{NodeMsg, Section},
-    DstLocation, MsgKind, WireMsg,
+    DstLocation, EndUser, MsgKind, WireMsg,
 };
+use crate::node::RegisterStorage;
 use crate::routing::{
     core::{Core, SendStatus},
     error::Result,
@@ -54,6 +55,10 @@ impl Dispatcher {
         }
     }
 
+    pub(super) async fn get_register_storage(&self) -> RegisterStorage {
+        self.core.read().await.register_storage.clone()
+    }
+
     /// Handles the given command and transitively any new commands that are produced during its
     /// handling.
     pub(super) async fn handle_commands(self: Arc<Self>, command: Command) -> Result<()> {
@@ -108,6 +113,18 @@ impl Dispatcher {
                     .handle_message(sender, wire_msg)
                     .await
             }
+            Command::HandleDataMessage {
+                msg_id,
+                user,
+                msg,
+                data_auth,
+            } => {
+                self.core
+                    .read()
+                    .await
+                    .handle_data_msg_received(msg_id, msg, user, data_auth)
+                    .await
+            }
             Command::HandleTimeout(token) => self.core.write().await.handle_timeout(token),
             Command::HandleAgreement { proposal, sig } => {
                 self.core
@@ -149,6 +166,7 @@ impl Dispatcher {
                 self.send_message(&recipients, delivery_group_size, wire_msg)
                     .await
             }
+            Command::ParseAndSendWireMsg(wire_msg) => self.send_wire_message(wire_msg).await,
             Command::RelayMessage(wire_msg) => {
                 if let Some(cmd) = self.core.write().await.relay_message(wire_msg).await? {
                     Ok(vec![cmd])
@@ -162,7 +180,7 @@ impl Dispatcher {
                 .into_iter()
                 .collect()),
             Command::HandleRelocationComplete { node, section } => {
-                self.handle_relocation_complete(node, section).await;
+                self.handle_relocation_complete(node, section).await?;
                 Ok(vec![])
             }
             Command::SetJoinsAllowed(joins_allowed) => {
@@ -283,6 +301,44 @@ impl Dispatcher {
         Ok(cmds)
     }
 
+    /// Send a message.
+    /// Messages sent here, either section to section or node to node.
+    pub(super) async fn send_wire_message(&self, mut wire_msg: WireMsg) -> Result<Vec<Command>> {
+        if let DstLocation::EndUser(EndUser { socket_id, xorname }) = wire_msg.dst_location() {
+            if self.core.read().await.section().prefix().matches(xorname) {
+                let addr = self.core.read().await.get_socket_addr(*socket_id).copied();
+
+                if let Some(socket_addr) = addr {
+                    // Send a message to a client peer.
+                    // Messages sent to a client are not signed
+                    // or validated as part of the routing library.
+                    debug!("Sending client msg to {:?}", socket_addr);
+
+                    let recipients = vec![(*xorname, socket_addr)];
+                    wire_msg.set_dst_section_pk(
+                        *self.core.read().await.section_chain().clone().last_key(),
+                    );
+
+                    let command = Command::SendMessage {
+                        recipients,
+                        wire_msg,
+                    };
+                    return Ok(vec![command]);
+                } else {
+                    debug!(
+                        "Could not find socketaddr corresponding to socket_id {:?}",
+                        socket_id
+                    );
+                    debug!("Relaying user message instead.. (Command::RelayMessage)");
+                }
+            } else {
+                debug!("Relaying message with sending user message (Command::RelayMessage)");
+            }
+        }
+
+        Ok(vec![Command::RelayMessage(wire_msg)])
+    }
+
     async fn handle_schedule_timeout(&self, duration: Duration, token: u64) -> Option<Command> {
         let mut cancel_rx = self.cancel_timer_rx.clone();
 
@@ -297,17 +353,19 @@ impl Dispatcher {
         }
     }
 
-    async fn handle_relocation_complete(&self, new_node: Node, new_section: Section) {
+    async fn handle_relocation_complete(&self, new_node: Node, new_section: Section) -> Result<()> {
         let previous_name = self.core.read().await.node().name();
         let new_keypair = new_node.keypair.clone();
 
         let mut core = self.core.write().await;
-        *core = core.relocated(new_node, new_section).await;
+        *core = core.relocated(new_node, new_section).await?;
 
         core.send_event(Event::Relocated {
             previous_name,
             new_keypair,
         })
         .await;
+
+        Ok(())
     }
 }
