@@ -8,8 +8,8 @@
 
 use crate::messaging::{
     data::DataMsg,
-    node::{NodeCmd, NodeCmdError, NodeEvent, NodeQuery, NodeQueryResponse},
-    DataAuthority, DstLocation, EndUser, MessageId, SrcLocation,
+    node::{NodeCmd, NodeQuery, NodeQueryResponse},
+    Authority, DataSigned, DstLocation, EndUser, MessageId, SrcLocation,
 };
 use bls::PublicKey as BlsPublicKey;
 use ed25519_dalek::Keypair;
@@ -117,7 +117,7 @@ pub enum Event {
         /// The content of the message.
         msg: Box<DataMsg>,
         /// Data authority
-        data_auth: DataAuthority,
+        data_auth: Authority<DataSigned>,
         /// The end user that sent the message.
         /// Its xorname is derived from the client public key,
         /// and the socket_id maps against the actual socketaddr
@@ -139,20 +139,6 @@ pub enum Event {
 pub enum MessageReceived {
     /// Cmds only sent a among Nodes in the network.
     NodeCmd(NodeCmd),
-    /// An error of a NodeCmd.
-    NodeCmdError {
-        /// The error.
-        error: NodeCmdError,
-        /// ID of causing cmd.
-        correlation_id: MessageId,
-    },
-    /// Events only sent among Nodes in the network.
-    NodeEvent {
-        /// Request.
-        event: NodeEvent,
-        /// ID of causing cmd.
-        correlation_id: MessageId,
-    },
     /// Queries is a read-only operation.
     NodeQuery(NodeQuery),
     /// The response to a query, containing the query result.
